@@ -126,12 +126,10 @@ class DrumRawClassifier:
         pairs = sorted(list(rhythm_count.items()), key=lambda x: -x[1])
         self.rhythms = np.array([pair[0] for pair in pairs])[:k]
 
-    def add_bar_class(self, midi_obj, bar_resolution=1920, indices=None):
-        drum_maps = get_drum_maps(midi_obj, bar_resolution=bar_resolution)
-        if indices is None:
-            indices = np.arange(drum_maps.shape[1])
+    def add_bar_class(self, midi_obj, bar_resolution=1920, drums=None):
+        drum_maps = get_drum_maps(midi_obj, bar_resolution=bar_resolution, drums=drums)
 
-        for bar, drum_map in enumerate(drum_maps.reshape(drum_maps.shape[0], len(indices) * drum_maps.shape[2])):
+        for bar, drum_map in enumerate(drum_maps.reshape(drum_maps.shape[0], len(drums) * drum_maps.shape[2])):
             rhythm_type = np.argmax(rhythm_similarity(drum_map, self.rhythms))
             marker = containers.Marker(text=f'drum rhythm {int(rhythm_type)}',
                                        time=bar * bar_resolution)
